package com.ruoyi.kaohe.mapper;

import java.util.List;
import com.ruoyi.kaohe.domain.KhEmpItem;

/**
 * 职工考核Mapper接口
 * 
 * @author hs
 * @date 2025-06-17
 */
public interface KhEmpItemMapper 
{
    /**
     * 查询职工考核
     * 
     * @param id 职工考核主键
     * @return 职工考核
     */
    public KhEmpItem selectKhEmpItemById(Long id);

    /**
     * 查询职工考核列表
     * 
     * @param khEmpItem 职工考核
     * @return 职工考核集合
     */
    public List<KhEmpItem> selectKhEmpItemList(KhEmpItem khEmpItem);

    /**
     * 新增职工考核
     * 
     * @param khEmpItem 职工考核
     * @return 结果
     */
    public int insertKhEmpItem(KhEmpItem khEmpItem);

    /**
     * 修改职工考核
     * 
     * @param khEmpItem 职工考核
     * @return 结果
     */
    public int updateKhEmpItem(KhEmpItem khEmpItem);

    /**
     * 删除职工考核
     * 
     * @param id 职工考核主键
     * @return 结果
     */
    public int deleteKhEmpItemById(Long id);

    /**
     * 批量删除职工考核
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteKhEmpItemByIds(Long[] ids);
}
