package com.ruoyi.kaohe.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.kaohe.domain.KhEmpItem;
import com.ruoyi.kaohe.service.IKhEmpItemService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 职工考核Controller
 * 
 * @author hs
 * @date 2025-06-17
 */
@RestController
@RequestMapping("/kaohe/emp_item")
public class KhEmpItemController extends BaseController
{
    @Autowired
    private IKhEmpItemService khEmpItemService;

    /**
     * 查询职工考核列表
     */
    @PreAuthorize("@ss.hasPermi('kaohe:emp_item:list')")
    @GetMapping("/list")
    public TableDataInfo list(KhEmpItem khEmpItem)
    {
        startPage();
        List<KhEmpItem> list = khEmpItemService.selectKhEmpItemList(khEmpItem);
        return getDataTable(list);
    }

    /**
     * 导出职工考核列表
     */
    @PreAuthorize("@ss.hasPermi('kaohe:emp_item:export')")
    @Log(title = "职工考核", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, KhEmpItem khEmpItem)
    {
        List<KhEmpItem> list = khEmpItemService.selectKhEmpItemList(khEmpItem);
        ExcelUtil<KhEmpItem> util = new ExcelUtil<KhEmpItem>(KhEmpItem.class);
        util.exportExcel(response, list, "职工考核数据");
    }

    /**
     * 获取职工考核详细信息
     */
    @PreAuthorize("@ss.hasPermi('kaohe:emp_item:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(khEmpItemService.selectKhEmpItemById(id));
    }

    /**
     * 新增职工考核
     */
    @PreAuthorize("@ss.hasPermi('kaohe:emp_item:add')")
    @Log(title = "职工考核", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody KhEmpItem khEmpItem)
    {
        return toAjax(khEmpItemService.insertKhEmpItem(khEmpItem));
    }

    /**
     * 修改职工考核
     */
    @PreAuthorize("@ss.hasPermi('kaohe:emp_item:edit')")
    @Log(title = "职工考核", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody KhEmpItem khEmpItem)
    {
        return toAjax(khEmpItemService.updateKhEmpItem(khEmpItem));
    }

    /**
     * 删除职工考核
     */
    @PreAuthorize("@ss.hasPermi('kaohe:emp_item:remove')")
    @Log(title = "职工考核", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(khEmpItemService.deleteKhEmpItemByIds(ids));
    }
}
